# universalEbookScraper
A simple script to scrape any ebook for a PDF file  

**Running**
- Navigate to the directory contaning "universalEbookScraper.py" and "requirements.txt"  
- Install requirements:  
`pip install -r requirements.txt`  
- Run:  
`python3 universalEbookScraper.py`  
If that doesn't work, try:  
`python universalEbookScraper.py`

**Output**  
- An image for each page in the `/images` directory
- A single PDF file with a separate page for each image
